@@ -45,7 +45,7 @@ class Energidataservice:
         end_date_str = (end_date + timedelta(days=1)).strftime("%Y-%m-%dT00:00")
         base_url = f"https://api.energidataservice.dk/dataset/Elspotprices?offset=0"
         url = f"{base_url}&start={start_date_str}&end={end_date_str}&filter={filters}&sort=HourUTC ASC"
-        indata_json = requests.get(url).json()['records']
+        indata_json = requests.get(url,verify = False).json()['records']
         for d in indata_json:
             d.update((k, datetime.strptime(v, '%Y-%m-%dT%H:%M:%S')) for k, v in d.items() if k in ['HourUTC', 'HourDK'])
         return indata_json
@@ -57,7 +57,7 @@ class Energidataservice:
         end_date_str = (end_date + timedelta(days=1)).strftime("%Y-%m-%dT00:00")
         base_url = f"https://api.energidataservice.dk/dataset/ProductionConsumptionSettlement?offset=0"
         url = f"{base_url}&start={start_date_str}&end={end_date_str}&filter={filters}&sort=HourUTC ASC"
-        indata_json = requests.get(url).json()['records']
+        indata_json = requests.get(url,verify = False).json()['records']
         for d in indata_json:
             d.update((k, datetime.strptime(v, '%Y-%m-%dT%H:%M:%S')) for k, v in d.items() if k in ['HourUTC', 'HourDK'])
         return indata_json
@@ -77,7 +77,7 @@ class Energidataservice:
         end_date_str = (end_date + timedelta(days=1)).strftime("%Y-%m-%dT00:00")
         base_url = f"https://api.energidataservice.dk/dataset/Transmissionlines?offset=0&sort=HourUTC ASC"
         url = f"{base_url}&start={start_date_str}&end={end_date_str}"
-        indata_json = requests.get(url).json()['records']
+        indata_json = requests.get(url, verify = False).json()['records']
         indata_json = [obs for obs in indata_json if obs['PriceArea'] == area]
         for d in indata_json:
             d.update(
@@ -100,7 +100,7 @@ class Energidataservice:
         base_url = f"https://api.energidataservice.dk/dataset/Forecasts_Hour?offset=0"
         url = f"{base_url}&start={start_date_str}&end={end_date_str}"
         # print(url)
-        indata_json = requests.get(url).json()['records']
+        indata_json = requests.get(url, verify = False).json()['records']
         indata_json = [obs for obs in indata_json if obs['PriceArea'] == area]
         for d in indata_json:
             d.update(
