@@ -9,7 +9,7 @@ import re
 
 def main():
     start_date=datetime(2021,1,1)
-    for commodity in ['ttf_gas','urea_ammonium','EUA']:
+    for commodity in ['ttf_gas','urea_ammonium','EUA','brent_oil'][-1:]:
         indata_list=Trading_economics.commodity_prices_df(commodity,start_date)
         utils.prt(indata_list[-10:])
 
@@ -52,6 +52,8 @@ class Trading_economics():
               'url_data': 'https://markets.tradingeconomics.com/chart?interval=1d&securify=new&url=/commodity/eu-natural-gas&s=ngeu:com'},
             {'commodity': 'urea_ammonium', 'url_site': 'https://tradingeconomics.com/commodity/urea-ammonium',
               'url_data': 'https://markets.tradingeconomics.com/chart?interval=1d&securify=new&url=/commodity/urea-ammonium&s=uaneu:com'},
+            {'commodity': 'brent_oil', 'url_site': 'https://tradingeconomics.com/commodity/brent-crude-oil',
+             'url_data': 'https://markets.tradingeconomics.com/chart?interval=1d&securify=new&url=/commodity/brent-crude-oil&s=co1:com'},
             {'commodity': 'EUA', 'url_site': 'https://tradingeconomics.com/commodity/carbon',
               'url_data': 'https://markets.tradingeconomics.com/chart?interval=1d&securify=new&url=/commodity/carbon&s=eecxm:ind'},
         ]
